from setuptools import setup

setup(name='orp-distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['orp-distributions'],
      author = 'Osvaldo Rosales',
      zip_safe=False)
